==> openshift-model-machine-5.12.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/ObjectMetaBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ObjectMetaBuilder extends io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta,io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaBuilder>{
  public ObjectMetaBuilder() {
    this(false);
  }
  public ObjectMetaBuilder(java.lang.Boolean validationEnabled) {
    this(new ObjectMeta(), validationEnabled);
  }
  public ObjectMetaBuilder(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluent<?> fluent) {
    this(fluent, false);
  }
  public ObjectMetaBuilder(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ObjectMeta(), validationEnabled);
  }
  public ObjectMetaBuilder(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta instance) {
    this(fluent, instance, false);
  }
  public ObjectMetaBuilder(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAnnotations(instance.getAnnotations()); 
    fluent.withGenerateName(instance.getGenerateName()); 
    fluent.withLabels(instance.getLabels()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withOwnerReferences(instance.getOwnerReferences()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ObjectMetaBuilder(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta instance) {
    this(instance,false);
  }
  public ObjectMetaBuilder(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAnnotations(instance.getAnnotations()); 
    this.withGenerateName(instance.getGenerateName()); 
    this.withLabels(instance.getLabels()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withOwnerReferences(instance.getOwnerReferences()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta build() {
    ObjectMeta buildable = new ObjectMeta(fluent.getAnnotations(),fluent.getGenerateName(),fluent.getLabels(),fluent.getName(),fluent.getNamespace(),fluent.getOwnerReferences());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ObjectMetaBuilder that = (ObjectMetaBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machine-6.4.0-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/ObjectMetaBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ObjectMetaBuilder extends ObjectMetaFluentImpl<ObjectMetaBuilder> implements VisitableBuilder<ObjectMeta,ObjectMetaBuilder>{
  public ObjectMetaBuilder() {
    this(false);
  }
  public ObjectMetaBuilder(Boolean validationEnabled) {
    this(new ObjectMeta(), validationEnabled);
  }
  public ObjectMetaBuilder(ObjectMetaFluent<?> fluent) {
    this(fluent, false);
  }
  public ObjectMetaBuilder(ObjectMetaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ObjectMeta(), validationEnabled);
  }
  public ObjectMetaBuilder(ObjectMetaFluent<?> fluent,ObjectMeta instance) {
    this(fluent, instance, false);
  }
  public ObjectMetaBuilder(ObjectMetaFluent<?> fluent,ObjectMeta instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAnnotations(instance.getAnnotations()); 
    fluent.withGenerateName(instance.getGenerateName()); 
    fluent.withLabels(instance.getLabels()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withOwnerReferences(instance.getOwnerReferences()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ObjectMetaBuilder(ObjectMeta instance) {
    this(instance,false);
  }
  public ObjectMetaBuilder(ObjectMeta instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAnnotations(instance.getAnnotations()); 
    this.withGenerateName(instance.getGenerateName()); 
    this.withLabels(instance.getLabels()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withOwnerReferences(instance.getOwnerReferences()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ObjectMetaFluent<?> fluent;
  Boolean validationEnabled;
  public ObjectMeta build() {
    ObjectMeta buildable = new ObjectMeta(fluent.getAnnotations(),fluent.getGenerateName(),fluent.getLabels(),fluent.getName(),fluent.getNamespace(),fluent.getOwnerReferences());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
